@@ -2,7 +2,7 @@ import os
 from functools import wraps
 from fastapi import Request, Body
 
-from magicapi import app
+# from magicapi import app
 
 from magicapi.Globals.G import g
 from magicapi.Models.Task import Task, TaskParams
@@ -60,7 +60,7 @@ def run_in_background(f):
 
         return {"success": True, "message": ""}
 
-    app.include_router(new_r)
+    g.app.include_router(new_r)
 
     @wraps(f)
     def wrapper(*args, **kwargs):
