@@ -6,7 +6,7 @@ from fastapi import Depends
 from fastapi.security import OAuth2PasswordBearer, OAuth2PasswordRequestForm
 from .CurrentUser import CurrentUser
 
-from magicapi import router
+from magicapi import g
 import firebase_admin
 from firebase_admin import auth
 
@@ -43,7 +43,7 @@ def need_doorman_vars(f):
     return wrapper
 
 
-@router.post("/login_with_phone", tags=["Doorman"])
+@g.magic_router.post("/login_with_phone", tags=["Doorman"])
 @need_doorman_vars
 def login_with_phone(phone_number: PhoneNumber):
     body = {
@@ -55,7 +55,7 @@ def login_with_phone(phone_number: PhoneNumber):
     return resp
 
 
-@router.post("/token", tags=["Doorman"])
+@g.magic_router.post("/token", tags=["Doorman"])
 @need_doorman_vars
 def login(form_data: OAuth2PasswordRequestForm = Depends()):
     body = {
