@@ -6,7 +6,7 @@ import time
 
 from mangum import Mangum
 
-from fastapi import FastAPI, Request
+from fastapi import FastAPI, Request, APIRouter
 from fastapi.middleware.cors import CORSMiddleware
 
 from .config import settings
@@ -54,6 +54,20 @@ def add_addons(new_app):
     add_hello_world_testing_route(new_app)
 
 
+def add_background_tasks():
+    from magicapi.Decorators.background_tasks import run_in_background
+
+
+def make_magic_router(app: FastAPI):
+    from magicapi.RouteClasses import MagicCallLogger
+    magic_router = APIRouter(route_class=MagicCallLogger)
+    g.magic_router = magic_router
+
+
+def add_magic_routers():
+    g.app.include_router(g.magic_router)
+
+
 def create_app(config_settings=settings):
     print("creating_app", datetime.datetime.now())
     new_app = FastAPI(
@@ -63,7 +77,9 @@ def create_app(config_settings=settings):
     )
 
     add_addons(new_app)
-
+    g.app = new_app
+    add_background_tasks()
+    make_magic_router(g.app)
     return new_app
 
 
@@ -78,4 +94,5 @@ def create_handler(app):
         response = asgi_handler(event, context)
         return response
 
+    g.handler = handler
     return handler
